==> monodevelop-2.0.tar.bz2: monodevelop-2.0/src/addins/MonoDevelop.DesignerSupport/MonoDevelop.DesignerSupport.Toolbox/CodeTemplateToolboxProvider.cs <==
// 
// CodeTemplateToolboxProvider.cs
// 
// Author:
//   Michael Hutchinson <mhutchinson@novell.com>
// 
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Ide.CodeTemplates;

namespace MonoDevelop.DesignerSupport.Toolbox
{
	
	public class CodeTemplateToolboxProvider : IToolboxDynamicProvider
	{
		static string category = MonoDevelop.Core.GettextCatalog.GetString ("Text Snippets");
		
		public System.Collections.Generic.IEnumerable<ItemToolboxNode> GetDynamicItems (IToolboxConsumer consumer)
		{
			MonoDevelop.Ide.Gui.Content.IExtensibleTextEditor editor 
				= consumer as MonoDevelop.Ide.Gui.Content.IExtensibleTextEditor;
			if (editor != null) {
				CodeTemplateGroup group = CodeTemplateService.GetTemplateGroupPerFilename (editor.Name);
				if (group != null) {
					foreach (CodeTemplate ct in group.Templates) {
						string text = ct.Text.Replace ("|", string.Empty);
						TextToolboxNode n = new TextToolboxNode (text);
						n.Description = ct.Description;
						n.Name = ct.Shortcut;
						n.Category = category;
						yield return n;
					}
				}
			}
		}
		
		public event EventHandler ItemsChanged;
	}
}

==> monodevelop-2.6.0.1.tar.bz2: monodevelop-2.6.0.1/src/addins/MonoDevelop.DesignerSupport/MonoDevelop.DesignerSupport.Toolbox/CodeTemplateToolboxProvider.cs <==
// 
// CodeTemplateToolboxProvider.cs
// 
// Author:
//   Michael Hutchinson <mhutchinson@novell.com>
// 
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Ide.CodeTemplates;
using MonoDevelop.Ide;

namespace MonoDevelop.DesignerSupport.Toolbox
{
	
	public class CodeTemplateToolboxProvider : IToolboxDynamicProvider
	{
		static string category = MonoDevelop.Core.GettextCatalog.GetString ("Text Snippets");
		
		public System.Collections.Generic.IEnumerable<ItemToolboxNode> GetDynamicItems (IToolboxConsumer consumer)
		{
			
			MonoDevelop.Ide.Gui.Content.IExtensibleTextEditor editor 
				= consumer as MonoDevelop.Ide.Gui.Content.IExtensibleTextEditor;
			if (editor != null) {
				foreach (CodeTemplate ct in CodeTemplateService.GetCodeTemplatesForFile (editor.Name)) {
					if (ct.CodeTemplateContext != CodeTemplateContext.Standard)
						continue;
					TemplateToolboxNode n = new TemplateToolboxNode (ct);
					n.Description = ct.Description;
					n.Name = ct.Shortcut;
					n.Category = category;
					n.Icon = ImageService.GetPixbuf ("md-template", Gtk.IconSize.Menu);
					yield return n;
				}
			}
			yield break;
		}
		
		public event EventHandler ItemsChanged;
	}
}
